<?php
/******************************************************************************
** codebase.php
*  Coppermine 1.6.x Plugin - suppressor. Created by KF to suppress display of file information
*  Version 1.0
* @since  1.6.22
******************************************************************************/

/******************************************************************************
 * The code here gets awkward because of languages. The Configuration is all in English and the config screen can be changed 
 * in the language file for the plugin. Picking up languages for the config from language files elsewhere 
 * in Coppermine would need custom language code in the plugin to manipulate the files and is not feasible.
 * 
 * In the running of the plugin, language files are available and have to be used because the items of picture info are
 * named in the chosen language. The plugin settings are all coded using the English names and pic info has to be checked against
 * the chosen language in suppressor_filter_pic_info_item.  Menu items do not have localised names in the code where the checking is done.
 * 
******************************************************************************/

// Make sure that this file can't be accessed directly, but only from within the Coppermine user interface
if (!defined('IN_COPPERMINE')) {
    die('Not in Coppermine...');
}

// Define plugin actions here
$thisplugin->add_action('plugin_install', 'suppressor_install');
$thisplugin->add_action('plugin_uninstall', 'suppressor_uninstall');
$thisplugin->add_action('plugin_cleanup', 'suppressor_cleanup');

// Define plugin filters here
$thisplugin->add_filter('file_info', 'suppressor_filter_pic_info');
$thisplugin->add_filter('sub_menu', 'suppressor_filter_menu');

function suppressor_init_settings(&$suppressor_setting) {
    // These are the indexes into the configuration string for the settings, starting from 1
    $suppressor_setting['Filename']            = 1;
    $suppressor_setting['Filesize']            = 2;
    $suppressor_setting['Date_added']          = 3;
    $suppressor_setting['Dimensions']          = 4;
    $suppressor_setting['Displayed']           = 5;
    $suppressor_setting['DateTime_Original']   = 6;
    $suppressor_setting['URL']                 = 7;
    $suppressor_setting['Favorites']           = 8;
    $suppressor_setting['Search']              = 9;
    $suppressor_setting['Top_rated']           = 10;
    $suppressor_setting['Most_viewed']         = 11;
    $suppressor_setting['Last_Comments']       = 12;
    $suppressor_setting['Last_Uploads']        = 13;
    return true;
} 

function suppressor_filter_pic_info_item(&$file_info, $suppressor_setting, $plugin_name, $screen_name) {
    // Need to use the local language version ($screen_name) for the check as this is used in displayimage.php
    global $CONFIG;
    $key_string = $screen_name;
    if (substr($CONFIG['suppressor_settings'], ($suppressor_setting[$plugin_name] - 1), 1) == "0") {   // Check if config setting (substr counts from zero) is 0
        $file_info = array_diff($file_info, array($file_info[$key_string]));          // If it is, remove item of file info from the array of retrieved info 
        return true;
    } else {
        return false;
    }
}

function suppressor_filter_pic_info($file_info) {
    global $lang_common, $lang_picinfo;
    suppressor_init_settings($file_info_setting);
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'Filename',          $lang_common['filename'] );
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'Filesize',          $lang_common['filesize'] );
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'Date_added',        $lang_picinfo['Date Added'] );
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'Dimensions',        $lang_picinfo['Dimensions'] );
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'Displayed',         $lang_picinfo['Displayed'] );
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'DateTime_Original', $lang_picinfo['DateTimeOriginal'] );
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'URL',               $lang_picinfo['URL'] );
    suppressor_filter_pic_info_item($file_info, $file_info_setting, 'Favorites',         $lang_picinfo['addFavPhrase']);
    return $file_info;
}

function suppressor_filter_menu_item(&$menu_changed, $file_info_to_check, &$buttonset, $menu_link) {
    global $CONFIG;
    if (substr($CONFIG['suppressor_settings'], ($file_info_to_check - 1), 1) == "0") {   // If this is a menu item configured to be suppressed
        $button_count = 0;
        foreach ($buttonset as $button) {                                   // Loop through the buttons. Include all except the favorites menu
            if ($button[0] <> $menu_link) {
                $buttons_out[$button_count] = $button;
                $button_count++;
            } 
        }
        $buttonset = $buttons_out;  // Return with revised buttons / links
        $menu_changed = true;
    } 
}

function suppressor_filter_menu($buttonset) {  
    suppressor_init_settings($file_info_setting);
    $menu_changed = false;
    suppressor_filter_menu_item($menu_changed, $file_info_setting['Favorites'],     $buttonset, '{FAV_LNK}');
    suppressor_filter_menu_item($menu_changed, $file_info_setting['Search'],        $buttonset, '{SEARCH_LNK}');
    suppressor_filter_menu_item($menu_changed, $file_info_setting['Top_rated'],     $buttonset, '{TOPRATED_LNK}');
    suppressor_filter_menu_item($menu_changed, $file_info_setting['Most_viewed'],   $buttonset, '{TOPN_LNK}');
    suppressor_filter_menu_item($menu_changed, $file_info_setting['Last_Comments'], $buttonset, '{LASTCOM_LNK}');
    suppressor_filter_menu_item($menu_changed, $file_info_setting['Last_Uploads'],  $buttonset, '{LASTUP_LNK}');
    // If we changed anything, need to be sure that the last item in the array of menu items has the caret divider between items set to blank
    if ($menu_changed) {
        $last_item_index = count($buttonset) - 1;    //Noting that array starts from zero
        $buttonset[$last_item_index][4] = '';        //Blank the caret
        $buttonset[$last_item_index][5] = '';   
    }
    return($buttonset); 
}

function suppressor_install() {
    global $CONFIG, $suppressor_default; 

    cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) 
                 VALUES ('suppressor_settings', {$suppressor_default})
                ");
    return true;
}

function suppressor_uninstall() {
    global $CONFIG, $lang_errors;
    $superCage = Inspekt::makeSuperCage();
    if (!checkFormToken()) {
        cpg_die(ERROR, $lang_errors['invalid_form_token'], __FILE__, __LINE__);
    }
	if ($superCage->post->keyExists('suppressor_submit') && $superCage->post->keyExists('suppressor_uninstall_type')) {
		if ($superCage->post->getInt('suppressor_uninstall_type') == 1) {
            // Delete the plugin config records
            cpg_db_query("DELETE FROM {$CONFIG['TABLE_CONFIG']} WHERE name IN ( 
                        'suppressor_settings' 
                       )");
        }
        return true;
    } else {
        return 1;
    }
}

function suppressor_cleanup ()  {
	global $lang_common, $superCage, $lang_plugin_suppressor;

	echo '<form name="cpgform" id="cpgform" action="'.$superCage->server->getEscaped('REQUEST_URI').'" method="post">';
	echo <<<EOT
	<br />{$lang_plugin_suppressor['uninstall_type']}<br />
	<input type="radio" name="suppressor_uninstall_type" id="suppressor_full" value="1" checked="checked" /> 
        <label for="suppressor_full">{$lang_plugin_suppressor['uninstall_full']}</label><br />
	<input type="radio" name="suppressor_uninstall_type" id="suppressor_partial" value="2"  /> 
        <label for="suppressor_partial">{$lang_plugin_suppressor['uninstall_partial']}</label><br />
	<br /><input type="submit" name="suppressor_submit" value="{$lang_common['continue']}" class="button" style="padding-right:5px;padding-left:5px" />
	</form>
EOT;
}
